# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# If you don't want to run the unit tests
# give rpmbuild option '--without tests'

%define with_tests %{!?_without_tests:1}%{?_without_tests:0}
%define without_tests %{?_without_tests:1}%{!?_without_tests:0}

%define section free

Summary:        JBoss Serialization
URL:            http://labs.jboss.com/portal/index.html?ctrl:id=page.default.info&project=jbossremoting
Source0:        jboss-serialization-1.0.0-RC2-src.tar.gz
#cvs -d:pserver:anonymous@anoncvs.forge.jboss.com:/cvsroot/jboss export -r VERSION_1_0_0_RC2 jboss-serialization
Patch0:         jboss-serialization-build_xml.patch


Name:           jboss-serialization
Version:        1.0.0
Release:        0.rc2.3jpp
Epoch:          0
License:        LGPL
Group:          Development/Java
Vendor:         JPackage Project
Distribution:   JPackage
BuildArch:      noarch
BuildRequires:  jpackage-utils >= 0:1.6
BuildRequires:  ant >= 0:1.6
BuildRequires:  concurrent
BuildRequires:  jakarta-commons-logging
BuildRequires:  jboss4-common
BuildRequires:  jboss-jrunit
BuildRequires:  jcommon0
BuildRequires:  jfreechart0
BuildRequires:  jgroups >= 0:2.2.9.2
BuildRequires:  junit
BuildRequires:  log4j
Requires:       jpackage-utils >= 0:1.6
Requires:       concurrent
Requires:       jakarta-commons-logging
Requires:       jboss4-common
Requires:       jcommon0
Requires:       jfreechart0
Requires:       jgroups >= 0:2.2.9.2
Requires:       log4j
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
We (java developers) have accepted over the years 
java.io.ObjectInputStream and java.io.ObjectOutputStream 
being slow when dealing with writeObject operations.
We then started using Externalizable objects as a faster 
approach for serialization, but even that way was slow when 
using writeObject operations inside externalizable classes.
Recently we discovered that most of the problems in 
JavaSerialization are related to static synchronized caching, 
what causes CPU spikes and also diminishes scaling capabilities.
With JBossSerialization we have done internal benchmarks and we 
have realized at least 2 times faster serialization with this 
library. These benchmarks are commited into our CVS repository 
(as testcases) and they are publicly available.
The main feature in JBossSerialization besides performance, is 
Smart Cloning. Smart cloning is the capability of the reuse of 
final fields among different class loaders doing exactly what 
serialization does, without the need of convert every field into 
a byteArray. This approach is at least 10 times faster than using 
serialization over a byte array.


%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}

%prep
%setup -q -n %{name}
chmod -R go=u-w *
for j in $(find . -name "*.jar"); do
    mv $j $j.no
done

%patch0 -b .sav

%build
pushd libs
#BUILD/jboss-serialization/libs/commons-logging.jar.no
ln -sf $(build-classpath commons-logging) .
#BUILD/jboss-serialization/libs/concurrent.jar.no
ln -sf $(build-classpath concurrent) .
#BUILD/jboss-serialization/libs/jboss-common.jar.no
ln -sf $(build-classpath jboss4/jboss-common) .
#BUILD/jboss-serialization/libs/jcommon-1.0.0-rc1.jar.no
ln -sf $(build-classpath jcommon0) .
#BUILD/jboss-serialization/libs/jfreechart-1.0.0-rc1.jar.no
ln -sf $(build-classpath jfreechart0) .
#BUILD/jboss-serialization/libs/jgroups.jar.no
ln -sf $(build-classpath jgroups) .
#BUILD/jboss-serialization/libs/jrunit.jar.no
ln -sf $(build-classpath jboss-jrunit) jrunit.jar
#BUILD/jboss-serialization/libs/junit.jar.no
ln -sf $(build-classpath junit) .
#BUILD/jboss-serialization/libs/log4j.jar.no
ln -sf $(build-classpath log4j) .
popd

%if %{with_tests}
export ANT_OPTS="-Djava.net.preferIPv4Stack=true"
ant jar javadocs run-tests 
%else
ant jar javadocs
%endif


%install
rm -rf $RPM_BUILD_ROOT

# jar
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}
install -p -m 0644 build/jar/%{name}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr build/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

# manual
install -d -m 0755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp docs/notes.txt   $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -sf %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(-,root,root,-)
%{_javadir}/*
%doc %{_docdir}/%{name}-%{version}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

%changelog
* Thu Mar 15 2007 Ralph Apel <r.apel at r-apel.de> 0:1.0.0-0.rc2.3jpp
- (B)R jfreechart0, jcommon0

* Wed May 31 2006 Ralph Apel <r.apel at r-apel.de> 0:1.0.0-0.rc2.2jpp
- add -Djava.net.preferIPv4Stack=true on each JVM
* Wed May 03 2006 Ralph Apel <r.apel at r-apel.de> 0:1.0.0-0.rc2.1jpp
- First JPP-1.7 release
